@@ -1,9 +1,9 @@
 package WG::API::Auth;
 
-use 5.014;
 use Moo;
+with 'WG::API::Base';
 
-extends 'WG::API';
+use constant api_uri => '//api.worldoftanks.ru/';
 
 =head1 NAME
 
@@ -11,70 +11,98 @@ WG::API::Auth  - Auth-module with using OpenID for work with WG PAPI
 
 =head1 VERSION
 
-Version v0.8
+Version v0.9
 
 =cut
 
-our $VERSION = 'v0.8';
+our $VERSION = 'v0.9';
 
 =head1 SYNOPSIS
 
 This module implements the possibility of authorization, prolongate and logout from the center of development.
 
-    use WG::API::Auth;
+    use WG::API;
 
-    my $response = WG::API::Auth->new({ application_id => 'demo' })->login({ nofollow => '1', redirect_uri => 'yoursite.com/response' } );
+    my $response = WG::API->new( application_id => 'demo' )->auth()->login( nofollow => '1', redirect_uri => 'yoursite.com/response' );
 
     my $redirect_uri = $response->{ 'location' };
     ...
 
 =head1 METHODS
 
-=head2 AUTH
+=over 1
 
-=head3 login
+=item B<login>
 
 Method authenticates user based on Wargaming.net ID (OpenID) which is used in World of Tanks, World of Tanks Blitz, World of Warplanes, and WarGag.ru. To log in, player must enter email and password used for creating account, or use a social network profile. Authentication is not available for iOS Game Center users in the following cases: the account is not linked to a social network account, or email and password are not specified in the profile.
 
 Information on authorization status is sent to URL specified in redirect_uri parameter.
 
+=back
+
 =cut
 
-sub login { 
+sub login {
     my $self = shift;
-    $self->_request( 'get', 'auth/login', ['expires_at', 'redirect_uri', 'display', 'nofollow'], undef, @_ );
 
-    return $self->status eq 'ok' ? $self->response : undef;
-}  
+    return $self->_request( 'get', 'wot/auth/login/', [ 'expires_at', 'redirect_uri', 'display', 'nofollow' ], undef, @_ );
+}
 
-=head3 prolongate
+=over 1
+
+=item B<prolongate>
 
 Method generates new access_token based on the current token.
 
 This method is used when the player is still using the application but the current access_token is about to expire.
 
+=over 2
+
+=item I<required fields:>
+
+    access_token - Access token for the private data of a user's account; can be received via the authorization method; valid within a stated time period
+
+=back
+
+=back
+
 =cut
 
-sub prolongate { shift->_request( 'get', 'auth/prolongate', ['access_token', 'expires_at'], ['access_token'], @_ ) }
+sub prolongate {
+    my $self = shift;
 
-=head3 logout
+    return $self->_request( 'post', 'wot/auth/prolongate/', [ 'access_token', 'expires_at' ], ['access_token'], @_ );
+}
+
+=over 1
+
+=item B<logout>
 
 Method deletes user's access_token.
 
 After this method is called, access_token becomes invalid.
 
+=over 2
+
+=item I<required fields:>
+
+    access_token - Access token for the private data of a user's account; can be received via the authorization method; valid within a stated time period
+
+=back
+
+=back
+
 =cut
 
-sub logout { shift->_request( 'get', 'auth/logout', ['access_token'], ['access_token'], @_ ) }
+sub logout {
+    my $self = shift;
 
-has api_uri => (
-    is      => 'ro',
-    default => 'api.worldoftanks.ru/wot',
-);
+    return $self->_request( 'post', 'wot/auth/logout/', ['access_token'], ['access_token'], @_ );
+}
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<cynovg at cpan.org>, or through the web interface at L<https://github.com/cynovg/WG-API/issues>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to C<cynovg at cpan.org>, or through the web interface at L<https://gitlab.com/cynovg/WG-API/issues>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
 
@@ -86,9 +114,9 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: GitHub's request tracker (report bugs here)
+=item * RT: Gitlab's request tracker (report bugs here)
 
-L<https://github.com/cynovg/WG-API/issues>
+L<https://gitlab.com/cynovg/WG-API/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -100,7 +128,7 @@ L<http://cpanratings.perl.org/d/WG-API>
 
 =item * Search CPAN
 
-L<http://search.cpan.org/dist/WG-API/>
+L<https://metacpan.org/pod/WG::API>
 
 =back
 
@@ -111,11 +139,11 @@ L<http://search.cpan.org/dist/WG-API/>
 
 =head1 SEE ALSO
 
-WG API Reference L<http://ru.wargaming.net/developers/>
+WG API Reference L<https://developers.wargaming.net/>
 
 =head1 AUTHOR
 
-cynovg , C<< <cynovg at cpan.org> >>
+Cyrill Novgorodcev , C<< <cynovg at cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -160,4 +188,4 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-1; # End of WG::API::Auth
+1;    # End of WG::API::Auth
