@@ -4,7 +4,7 @@ use Modern::Perl '2015';
 use Moo::Role;
 
 use WG::API::Error;
-use HTTP::Tiny;
+use LWP::UserAgent;
 use JSON;
 use Data::Dumper;
 use Log::Any qw($log);
@@ -15,11 +15,11 @@ use URI::QueryParam;
 
 =head1 VERSION
 
-Version v0.13
+Version v0.9
 
 =cut
 
-our $VERSION = 'v0.13';
+our $VERSION = 'v0.9';
 
 =head1 SYNOPSIS
 
@@ -27,7 +27,7 @@ Base class for all instances
 
 =cut
 
-requires '_api_uri';
+requires 'api_uri';
 
 =head1 ATTRIBUTES
 
@@ -35,7 +35,9 @@ requires '_api_uri';
 
 =item I<application_id*>
 
-Required application id: L<https://developers.wargaming.net/documentation/guide/getting-started/>
+Rerquired application id: L<https://developers.wargaming.net/documentation/guide/getting-started/>
+
+=back
 
 =cut
 
@@ -44,8 +46,12 @@ has application_id => (
     require => 1,
 );
 
+=over 1
+
 =item I<language>
 
+=back
+
 =cut
 
 has language => (
@@ -53,30 +59,44 @@ has language => (
     default => sub {'ru'},
 );
 
+=over 1
+
 =item I<status>
 
 Return request status
 
+=back
+
 =cut
 
 has status => ( is => 'rw', );
 
+=over 1
+
 =item I<response>
 
 Return response
 
+=back
+
 =cut
 
 has response => ( is => 'rw', );
 
+=over 1
+
 =item I<meta_data>
 
 Return meta data from response
 
+=back
+
 =cut
 
 has meta_data => ( is => 'rw', );
 
+=over 1
+
 =item I<debug>
 
 Get current debug mode
@@ -99,31 +119,37 @@ has debug => (
 
 Returns a user agent instance
 
+=back
+
 =cut
 
-#@returns HTTP::Tiny
+#@returns LWP::UserAgent
 has ua => (
     is      => 'ro',
-    default => sub {
-        require HTTP::Tiny;
-        require IO::Socket::SSL;
-        HTTP::Tiny->new;
-    },
+    default => sub { LWP::UserAgent->new() },
 );
 
+=over 1
+
 =item B<error>
 
 Returns a WG::API::Error instance if defined;
 
+=back
+
 =cut
 
 #@returns WG::API::Error
 has error => ( is => 'rw', );
 
+=over 1
+
 =item B<set_debug>
 
 Set debug mode
 
+=back
+
 =over 1
 
 =item B<log>
@@ -132,8 +158,6 @@ Logger
 
 =back
 
-=back
-
 =cut
 
 sub log {
@@ -189,7 +213,7 @@ sub _get {
     #@type HTTP::Response
     my $response = $self->_raw_get( $self->_build_url($uri) . $self->_build_get_params( $params, %passed_params ) );
 
-    return $self->_parse( $response->{'status'} eq '200' ? decode_json $response->{'content'} : undef );
+    return $self->_parse( $response->is_success ? decode_json $response->decoded_content : undef );
 }
 
 sub _post {
@@ -198,7 +222,7 @@ sub _post {
     #@type HTTP::Response
     my $response = $self->_raw_post( $self->_build_url($uri), $self->_build_post_params( $params, %passed_params ) );
 
-    return $self->_parse( $response->{'status'} eq '200' ? decode_json $response->{'content'} : undef );
+    return $self->_parse( $response->is_success ? decode_json $response->decoded_content : undef );
 }
 
 sub _parse {
@@ -249,7 +273,7 @@ sub _parse {
 sub _build_url {
     my ( $self, $uri ) = @_;
 
-    my $url = URI->new( $self->_api_uri );
+    my $url = URI->new( $self->api_uri );
     $url->scheme("https");
     $url->path($uri);
 
@@ -296,7 +320,7 @@ sub _raw_post {
 
     $self->log( sprintf "METHOD POST, URL %s, %s\n", $url, Dumper $params );
 
-    return $self->ua->post_form( $url, $params );
+    return $self->ua->post( $url, $params );
 }
 
 =head1 BUGS
