@@ -1,7 +1,6 @@
 package WG::API::Error;
 
 use Moo;
-use 5.014;
 
 =head1 NAME
 
@@ -9,12 +8,11 @@ WG::API::Error - module for work with API error
 
 =head1 VERSION
 
-Version v0.8
+Version v0.9
 
 =cut
 
-our $VERSION = 'v0.8';
-
+our $VERSION = 'v0.9';
 
 =head1 SYNOPSIS
 
@@ -50,7 +48,7 @@ Error code.
 =cut
 
 has code => (
-    is  => 'ro',
+    is       => 'ro',
     required => 1,
 );
 
@@ -65,7 +63,7 @@ Error message.
 =cut
 
 has message => (
-    is  => 'ro',
+    is       => 'ro',
     required => 1,
 );
 
@@ -80,7 +78,7 @@ Error field.
 =cut
 
 has field => (
-    is  => 'ro',
+    is       => 'ro',
     required => 1,
 );
 
@@ -95,7 +93,7 @@ Error value.
 =cut
 
 has value => (
-    is  => 'ro',
+    is       => 'ro',
     required => 1,
 );
 
@@ -109,13 +107,11 @@ RAW data from invalid response
 
 =cut
 
-has raw => (
-    is  => 'ro',
-);
+has raw => ( is => 'ro', );
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<cynovg at cpan.org>, or through the web interface at L<https://github.com/cynovg/WG-API/issues>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to C<cynovg at cpan.org>, or through the web interface at L<https://gitlab.com/cynovg/WG-API/issues>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
 
@@ -127,9 +123,9 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: GitHub's request tracker (report bugs here)
+=item * RT: Gitlab's request tracker (report bugs here)
 
-L<https://github.com/cynovg/WG-API/issues>
+L<https://gitlab.com/cynovg/WG-API/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -141,7 +137,7 @@ L<http://cpanratings.perl.org/d/WG-API>
 
 =item * Search CPAN
 
-L<http://search.cpan.org/dist/WG-API/>
+L<https://metacpan.org/pod/WG::API>
 
 =back
 
@@ -152,11 +148,11 @@ L<http://search.cpan.org/dist/WG-API/>
 
 =head1 SEE ALSO
 
-WG API Reference L<http://ru.wargaming.net/developers/>
+WG API Reference L<https://developers.wargaming.net/>
 
 =head1 AUTHOR
 
-cynovg , C<< <cynovg at cpan.org> >>
+Cyrill Novgorodcev , C<< <cynovg at cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -201,4 +197,4 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-1; # End of WG::API::Error
+1;    # End of WG::API::Error
